@@ -6,6 +6,8 @@ use strict;
 use warnings;
 use Data::Dump qw(pp);
 
+use Parley::Version;  our $VERSION = $Parley::VERSION;
+
 use DateTime;
 use DateTime::Format::Pg;
 use Text::Context::EitherSide;
@@ -85,6 +87,9 @@ __PACKAGE__->add_columns(
     is_nullable => 1,
     size => 8,
   },
+
+  admin_editor_id   => {},
+  locked            => {},
 );
 
 __PACKAGE__->set_primary_key("id");
@@ -101,6 +106,7 @@ __PACKAGE__->has_many(
 __PACKAGE__->belongs_to(
     "creator" => "Person",
     { 'foreign.id' => "self.creator_id" },
+    { join_type => 'left' }
 );
 __PACKAGE__->belongs_to(
     "reply_to" => "Post",
@@ -128,6 +134,10 @@ __PACKAGE__->has_many(
     "people" => "Person",
     { "foreign.last_post" => "self.id" },
 );
+__PACKAGE__->belongs_to(
+    "admin_editor" => "Person",
+    { 'foreign.id' => "self.admin_editor_id" },
+);
 
 
 
