@@ -1,37 +1,50 @@
 /*
-Copyright (c) 2007, Yahoo! Inc. All rights reserved.
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
 Code licensed under the BSD License:
 http://developer.yahoo.net/yui/license.txt
-version: 2.4.1
+version: 2.5.1
 */
-/**
+/*!
  * SWFObject v1.5: Flash Player detection and embed - http://blog.deconcept.com/swfobject/
  *
  * SWFObject is (c) 2007 Geoff Stearns and is released under the MIT License:
  * http://www.opensource.org/licenses/mit-license.php
- *
  */
-if(typeof deconcept == "undefined") var deconcept = new Object();
-if(typeof deconcept.util == "undefined") deconcept.util = new Object();
-if(typeof deconcept.SWFObjectUtil == "undefined") deconcept.SWFObjectUtil = new Object();
-deconcept.SWFObject = function(swf, id, w, h, ver, c, quality, xiRedirectUrl, redirectUrl, detectKey) {
-	if (!document.getElementById) { return; }
+var deconcept = deconcept || {};
+
+if(typeof deconcept.util == "undefined" || !deconcept.util)
+{
+	deconcept.util = {};
+}
+
+if(typeof deconcept.SWFObjectUtil == "undefined" || !deconcept.SWFObjectUtil)
+{
+	deconcept.SWFObjectUtil = {};
+}
+
+deconcept.SWFObject = function(swf, id, w, h, ver, c, quality, xiRedirectUrl, redirectUrl, detectKey)
+{
+	if(!document.getElementById) { return; }
 	this.DETECT_KEY = detectKey ? detectKey : 'detectflash';
 	this.skipDetect = deconcept.util.getRequestParameter(this.DETECT_KEY);
-	this.params = new Object();
-	this.variables = new Object();
-	this.attributes = new Array();
+	this.params = {};
+	this.variables = {};
+	this.attributes = [];
 	if(swf) { this.setAttribute('swf', swf); }
 	if(id) { this.setAttribute('id', id); }
 	if(w) { this.setAttribute('width', w); }
 	if(h) { this.setAttribute('height', h); }
 	if(ver) { this.setAttribute('version', new deconcept.PlayerVersion(ver.toString().split("."))); }
 	this.installedVer = deconcept.SWFObjectUtil.getPlayerVersion();
-	if (!window.opera && document.all && this.installedVer.major > 7) {
+	if (!window.opera && document.all && this.installedVer.major > 7)
+	{
 		// only add the onunload cleanup if the Flash Player version supports External Interface and we are in IE
 		deconcept.SWFObject.doPrepUnload = true;
 	}
-	if(c) { this.addParam('bgcolor', c); }
+	if(c)
+	{
+		this.addParam('bgcolor', c);
+	}
 	var q = quality ? quality : 'high';
 	this.addParam('quality', q);
 	this.setAttribute('useExpressInstall', false);
@@ -39,10 +52,16 @@ deconcept.SWFObject = function(swf, id, w, h, ver, c, quality, xiRedirectUrl, re
 	var xir = (xiRedirectUrl) ? xiRedirectUrl : window.location;
 	this.setAttribute('xiRedirectUrl', xir);
 	this.setAttribute('redirectUrl', '');
-	if(redirectUrl) { this.setAttribute('redirectUrl', redirectUrl); }
-}
-deconcept.SWFObject.prototype = {
-	useExpressInstall: function(path) {
+	if(redirectUrl)
+	{
+		this.setAttribute('redirectUrl', redirectUrl);
+	}
+};
+
+deconcept.SWFObject.prototype =
+{
+	useExpressInstall: function(path)
+	{
 		this.xiSWFPath = !path ? "expressinstall.swf" : path;
 		this.setAttribute('useExpressInstall', true);
 	},
@@ -68,7 +87,7 @@ deconcept.SWFObject.prototype = {
 		return this.variables;
 	},
 	getVariablePairs: function(){
-		var variablePairs = new Array();
+		var variablePairs = [];
 		var key;
 		var variables = this.getVariables();
 		for(key in variables){
@@ -78,6 +97,9 @@ deconcept.SWFObject.prototype = {
 	},
 	getSWFHTML: function() {
 		var swfNode = "";
+		var params = {};
+		var key = "";
+		var pairs = "";
 		if (navigator.plugins && navigator.mimeTypes && navigator.mimeTypes.length) { // netscape plugin architecture
 			if (this.getAttribute("doExpressInstall")) {
 				this.addVariable("MMplayerType", "PlugIn");
@@ -85,10 +107,10 @@ deconcept.SWFObject.prototype = {
 			}
 			swfNode = '<embed type="application/x-shockwave-flash" src="'+ this.getAttribute('swf') +'" width="'+ this.getAttribute('width') +'" height="'+ this.getAttribute('height') +'" style="'+ this.getAttribute('style') +'"';
 			swfNode += ' id="'+ this.getAttribute('id') +'" name="'+ this.getAttribute('id') +'" ';
-			var params = this.getParams();
-			 for(var key in params){ swfNode += [key] +'="'+ params[key] +'" '; }
-			var pairs = this.getVariablePairs().join("&");
-			 if (pairs.length > 0){ swfNode += 'flashvars="'+ pairs +'"'; }
+			params = this.getParams();
+			for(key in params){ swfNode += [key] +'="'+ params[key] +'" '; }
+			pairs = this.getVariablePairs().join("&");
+			if (pairs.length > 0){ swfNode += 'flashvars="'+ pairs +'"'; }
 			swfNode += '/>';
 		} else { // PC IE
 			if (this.getAttribute("doExpressInstall")) {
@@ -97,17 +119,18 @@ deconcept.SWFObject.prototype = {
 			}
 			swfNode = '<object id="'+ this.getAttribute('id') +'" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" width="'+ this.getAttribute('width') +'" height="'+ this.getAttribute('height') +'" style="'+ this.getAttribute('style') +'">';
 			swfNode += '<param name="movie" value="'+ this.getAttribute('swf') +'" />';
-			var params = this.getParams();
-			for(var key in params) {
+			params = this.getParams();
+			for(key in params) {
 			 swfNode += '<param name="'+ key +'" value="'+ params[key] +'" />';
 			}
-			var pairs = this.getVariablePairs().join("&");
+			pairs = this.getVariablePairs().join("&");
 			if(pairs.length > 0) {swfNode += '<param name="flashvars" value="'+ pairs +'" />';}
 			swfNode += "</object>";
 		}
 		return swfNode;
 	},
-	write: function(elementId){
+	write: function(elementId)
+	{
 		if(this.getAttribute('useExpressInstall')) {
 			// check to see if we need to do an express install
 			var expressInstallReqVer = new deconcept.PlayerVersion([6,0,65]);
@@ -118,120 +141,184 @@ deconcept.SWFObject.prototype = {
 				this.addVariable("MMdoctitle", document.title);
 			}
 		}
-		if(this.skipDetect || this.getAttribute('doExpressInstall') || this.installedVer.versionIsValid(this.getAttribute('version'))){
+		if(this.skipDetect || this.getAttribute('doExpressInstall') || this.installedVer.versionIsValid(this.getAttribute('version')))
+		{
 			var n = (typeof elementId == 'string') ? document.getElementById(elementId) : elementId;
 			n.innerHTML = this.getSWFHTML();
 			return true;
-		}else{
-			if(this.getAttribute('redirectUrl') != "") {
+		}
+		else
+		{
+			if(this.getAttribute('redirectUrl') !== "")
+			{
 				document.location.replace(this.getAttribute('redirectUrl'));
 			}
 		}
 		return false;
 	}
-}
+};
 
 /* ---- detection functions ---- */
-deconcept.SWFObjectUtil.getPlayerVersion = function(){
+deconcept.SWFObjectUtil.getPlayerVersion = function()
+{
+	var axo = null;
 	var PlayerVersion = new deconcept.PlayerVersion([0,0,0]);
-	if(navigator.plugins && navigator.mimeTypes.length){
+	if(navigator.plugins && navigator.mimeTypes.length)
+	{
 		var x = navigator.plugins["Shockwave Flash"];
-		if(x && x.description) {
+		if(x && x.description)
+		{
 			PlayerVersion = new deconcept.PlayerVersion(x.description.replace(/([a-zA-Z]|\s)+/, "").replace(/(\s+r|\s+b[0-9]+)/, ".").split("."));
 		}
-	}else if (navigator.userAgent && navigator.userAgent.indexOf("Windows CE") >= 0){ // if Windows CE
-		var axo = 1;
+	}
+	else if (navigator.userAgent && navigator.userAgent.indexOf("Windows CE") >= 0)
+	{ // if Windows CE
 		var counter = 3;
-		while(axo) {
-			try {
+		while(axo)
+		{
+			try
+			{
 				counter++;
 				axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash."+ counter);
 //				document.write("player v: "+ counter);
 				PlayerVersion = new deconcept.PlayerVersion([counter,0,0]);
-			} catch (e) {
+			}
+			catch(e)
+			{
 				axo = null;
 			}
 		}
-	} else { // Win IE (non mobile)
+	}
+	else
+	{ // Win IE (non mobile)
 		// do minor version lookup in IE, but avoid fp6 crashing issues
 		// see http://blog.deconcept.com/2006/01/11/getvariable-setvariable-crash-internet-explorer-flash-6/
-		try{
-			var axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash.7");
-		}catch(e){
-			try {
-				var axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash.6");
+		try
+		{
+			axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash.7");
+		}
+		catch(e)
+		{
+			try
+			{
+				axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash.6");
 				PlayerVersion = new deconcept.PlayerVersion([6,0,21]);
 				axo.AllowScriptAccess = "always"; // error if player version < 6.0.47 (thanks to Michael Williams @ Adobe for this code)
-			} catch(e) {
-				if (PlayerVersion.major == 6) {
+			}
+			catch(e)
+			{
+				if(PlayerVersion.major == 6)
+				{
 					return PlayerVersion;
 				}
 			}
-			try {
+			try
+			{
 				axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash");
-			} catch(e) {}
+			}
+			catch(e) {}
 		}
-		if (axo != null) {
+		
+		if(axo !== null)
+		{
 			PlayerVersion = new deconcept.PlayerVersion(axo.GetVariable("$version").split(" ")[1].split(","));
 		}
 	}
 	return PlayerVersion;
-}
-deconcept.PlayerVersion = function(arrVersion){
-	this.major = arrVersion[0] != null ? parseInt(arrVersion[0]) : 0;
-	this.minor = arrVersion[1] != null ? parseInt(arrVersion[1]) : 0;
-	this.rev = arrVersion[2] != null ? parseInt(arrVersion[2]) : 0;
-}
-deconcept.PlayerVersion.prototype.versionIsValid = function(fv){
-	if(this.major < fv.major) return false;
-	if(this.major > fv.major) return true;
-	if(this.minor < fv.minor) return false;
-	if(this.minor > fv.minor) return true;
-	if(this.rev < fv.rev) return false;
+};
+
+deconcept.PlayerVersion = function(arrVersion)
+{
+	this.major = arrVersion[0] !== null ? parseInt(arrVersion[0], 0) : 0;
+	this.minor = arrVersion[1] !== null ? parseInt(arrVersion[1], 0) : 0;
+	this.rev = arrVersion[2] !== null ? parseInt(arrVersion[2], 0) : 0;
+};
+
+deconcept.PlayerVersion.prototype.versionIsValid = function(fv)
+{
+	if(this.major < fv.major)
+	{
+		return false;
+	}
+	if(this.major > fv.major)
+	{
+		return true;
+	}
+	if(this.minor < fv.minor)
+	{
+		return false;
+	}
+	if(this.minor > fv.minor)
+	{
+		return true;
+	}
+	if(this.rev < fv.rev)
+	{
+		return false;
+	}
 	return true;
-}
+};
+
 /* ---- get value of query string param ---- */
-deconcept.util = {
-	getRequestParameter: function(param) {
+deconcept.util =
+{
+	getRequestParameter: function(param)
+	{
 		var q = document.location.search || document.location.hash;
-		if (param == null) { return q; }
-		if(q) {
+		if(param === null) { return q; }
+		if(q)
+		{
 			var pairs = q.substring(1).split("&");
-			for (var i=0; i < pairs.length; i++) {
-				if (pairs[i].substring(0, pairs[i].indexOf("=")) == param) {
-					return pairs[i].substring((pairs[i].indexOf("=")+1));
+			for(var i=0; i < pairs.length; i++)
+			{
+				if (pairs[i].substring(0, pairs[i].indexOf("=")) == param)
+				{
+					return pairs[i].substring((pairs[i].indexOf("=") + 1));
 				}
 			}
 		}
 		return "";
 	}
-}
+};
+
 /* fix for video streaming bug */
-deconcept.SWFObjectUtil.cleanupSWFs = function() {
+deconcept.SWFObjectUtil.cleanupSWFs = function()
+{
 	var objects = document.getElementsByTagName("OBJECT");
-	for (var i = objects.length - 1; i >= 0; i--) {
+	for(var i = objects.length - 1; i >= 0; i--)
+	{
 		objects[i].style.display = 'none';
-		for (var x in objects[i]) {
-			if (typeof objects[i][x] == 'function') {
+		for(var x in objects[i])
+		{
+			if(typeof objects[i][x] == 'function')
+			{
 				objects[i][x] = function(){};
 			}
 		}
 	}
-}
+};
+
 // fixes bug in some fp9 versions see http://blog.deconcept.com/2006/07/28/swfobject-143-released/
-if (deconcept.SWFObject.doPrepUnload) {
-	if (!deconcept.unloadSet) {
-		deconcept.SWFObjectUtil.prepUnload = function() {
+if(deconcept.SWFObject.doPrepUnload)
+{
+	if(!deconcept.unloadSet)
+	{
+		deconcept.SWFObjectUtil.prepUnload = function()
+		{
 			__flash_unloadHandler = function(){};
 			__flash_savedUnloadHandler = function(){};
 			window.attachEvent("onunload", deconcept.SWFObjectUtil.cleanupSWFs);
-		}
+		};
 		window.attachEvent("onbeforeunload", deconcept.SWFObjectUtil.prepUnload);
 		deconcept.unloadSet = true;
 	}
 }
+
 /* add document.getElementById if needed (mobile IE < 5) */
-if (!document.getElementById && document.all) { document.getElementById = function(id) { return document.all[id]; }}
+if(!document.getElementById && document.all)
+{
+	document.getElementById = function(id) { return document.all[id]; };
+}
 
 /* add some aliases for ease of use/backwards compatibility */
 var getQueryParamValue = deconcept.util.getRequestParameter;
@@ -267,7 +354,8 @@ YAHOO.widget.FlashAdapter = function(swfURL, containerID, attributes)
 	this._swfURL = swfURL;
 	
 	//embed the SWF file in the page
-	this._embedSWF(this._swfURL, containerID, attributes.id, attributes.version, attributes.backgroundColor, attributes.expressInstall);
+	this._embedSWF(this._swfURL, containerID, attributes.id, attributes.version,
+		attributes.backgroundColor, attributes.expressInstall, attributes.wmode);
 	
 	/**
 	 * Fires when the SWF is initialized and communication is possible.
@@ -326,11 +414,11 @@ YAHOO.extend(YAHOO.widget.FlashAdapter, YAHOO.util.AttributeProvider,
 	 * @method _embedSWF
 	 * @private
 	 */
-	_embedSWF: function(swfURL, containerID, swfID, version, backgroundColor, expressInstall)
+	_embedSWF: function(swfURL, containerID, swfID, version, backgroundColor, expressInstall, wmode)
 	{
 		//standard SWFObject embed
-		var swfObj = new deconcept.SWFObject(swfURL, swfID, "100%", "100%", version, backgroundColor, expressInstall);
-		
+		var swfObj = new deconcept.SWFObject(swfURL, swfID, "100%", "100%", version, backgroundColor);
+
 		if(expressInstall)
 		{
 			swfObj.useExpressInstall(expressInstall);
@@ -338,6 +426,12 @@ YAHOO.extend(YAHOO.widget.FlashAdapter, YAHOO.util.AttributeProvider,
 
 		//make sure we can communicate with ExternalInterface
 		swfObj.addParam("allowScriptAccess", "always");
+		
+		if(wmode !== null)
+		{
+			swfObj.addParam("wmode", wmode);
+		}
+		
 		//again, a useful ExternalInterface trick
 		swfObj.addVariable("allowedDomain", document.location.hostname);
 
@@ -356,6 +450,9 @@ YAHOO.extend(YAHOO.widget.FlashAdapter, YAHOO.util.AttributeProvider,
 			//this will allow the event handler to communicate with a YAHOO.widget.FlashAdapter
 			this._swf.owner = this;
 		}
+		else
+		{
+		}
 	},
 
 	/**
@@ -370,14 +467,10 @@ YAHOO.extend(YAHOO.widget.FlashAdapter, YAHOO.util.AttributeProvider,
 		switch(type)
 		{
 			case "swfReady":
-			{
    				this._loadHandler();
 				return;
-			}
 			case "log":
-			{
 				return;
-			}
 		}
 		
 		//be sure to return after your case or the event will automatically fire!
@@ -448,7 +541,10 @@ YAHOO.widget.FlashAdapter.eventHandler = function(elementID, event)
 		//fix for ie: if owner doesn't exist yet, try again in a moment
 		setTimeout(function() { YAHOO.widget.FlashAdapter.eventHandler( elementID, event ); }, 0);
 	}
-	else loadedSWF.owner._eventHandler(event);
+	else
+	{
+		loadedSWF.owner._eventHandler(event);
+	}
 };
 
 /**
@@ -597,6 +693,15 @@ YAHOO.extend(YAHOO.widget.Chart, YAHOO.widget.FlashAdapter,
 	 * @private
 	 */
 	_pollingInterval: null,
+	
+	/**
+	 * Indicates whether all attributes have been set and
+	 * the dataSource may be passed to the SWF.
+	 * @property _initialized
+	 * @type Boolean
+	 * @private
+	 */
+	_initialized: false,
 
 	/**
 	 * Public accessor to the unique name of the Chart instance.
@@ -779,6 +884,8 @@ YAHOO.extend(YAHOO.widget.Chart, YAHOO.widget.FlashAdapter,
 		
 		YAHOO.widget.Chart.superclass._loadHandler.call(this);
 		
+		this._initialized = true;
+		
 		if(this._dataSource)
 		{
 			this.set("dataSource", this._dataSource);
@@ -793,9 +900,14 @@ YAHOO.extend(YAHOO.widget.Chart, YAHOO.widget.FlashAdapter,
 	 */
 	_refreshData: function()
 	{
-		if(this._dataSource != null)
+		if(!this._initialized)
 		{
-			if(this._pollingID != null)
+			return;
+		}
+		
+		if(this._dataSource !== null)
+		{
+			if(this._pollingID !== null)
 			{
 				this._dataSource.clearInterval(this._pollingID);
 				this._pollingID = null;
@@ -832,17 +944,18 @@ YAHOO.extend(YAHOO.widget.Chart, YAHOO.widget.FlashAdapter,
 			//editing them directly.
 			var dataProvider = [];	
 			var seriesCount = 0;
-			if(this._seriesDefs)
+			var currentSeries = null;
+			var i = 0;
+			if(this._seriesDefs !== null)
 			{
 				seriesCount = this._seriesDefs.length;
-				for(var i = 0; i < seriesCount; i++)
+				for(i = 0; i < seriesCount; i++)
 				{
-					var currentSeries = this._seriesDefs[i];
+					currentSeries = this._seriesDefs[i];
 					var clonedSeries = {};
 					for(var prop in currentSeries)
 					{
-						
-						if(prop == "style" && currentSeries.style != null)
+						if(prop == "style" && currentSeries.style !== null)
 						{
 							clonedSeries.style = YAHOO.lang.JSON.stringify(currentSeries.style);
 							styleChanged = true;
@@ -851,7 +964,10 @@ YAHOO.extend(YAHOO.widget.Chart, YAHOO.widget.FlashAdapter,
 							//so null out the style property.
 							currentSeries.style = null;
 						}
-						else clonedSeries[prop] = currentSeries[prop];
+						else
+						{
+							clonedSeries[prop] = currentSeries[prop];
+						}
 					}
 					dataProvider.push(clonedSeries);
 				}
@@ -968,6 +1084,7 @@ YAHOO.extend(YAHOO.widget.Chart, YAHOO.widget.FlashAdapter,
 	_setSeriesDefs: function(value)
 	{
 		this._seriesDefs = value;
+		this._refreshData();
 	},
 
 	/**
@@ -1613,7 +1730,20 @@ YAHOO.widget.Series = function() {};
 
 YAHOO.widget.Series.prototype = 
 {
+	/**
+	 * The type of series.
+	 *
+	 * @property type
+	 * @type String
+	 */
 	type: null,
+	
+	/**
+	 * The human-readable name of the series.
+	 *
+	 * @property displayName
+	 * @type String
+	 */
 	displayName: null
 };
 
@@ -1631,7 +1761,20 @@ YAHOO.widget.CartesianSeries = function()
 
 YAHOO.lang.extend(YAHOO.widget.CartesianSeries, YAHOO.widget.Series,
 {
+	/**
+	 * The field used to access the x-axis value from the items from the data source.
+	 *
+	 * @property xField
+	 * @type String
+	 */
 	xField: null,
+	
+	/**
+	 * The field used to access the y-axis value from the items from the data source.
+	 *
+	 * @property yField
+	 * @type String
+	 */
 	yField: null
 });
 
@@ -1707,4 +1850,4 @@ YAHOO.lang.extend(YAHOO.widget.PieSeries, YAHOO.widget.Series,
 	categoryField: null
 });
 
-YAHOO.register("charts", YAHOO.widget.Chart, {version: "2.4.1", build: "742"});
+YAHOO.register("charts", YAHOO.widget.Chart, {version: "2.5.1", build: "984"});
