@@ -1,8 +1,8 @@
 /*
-Copyright (c) 2007, Yahoo! Inc. All rights reserved.
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
 Code licensed under the BSD License:
 http://developer.yahoo.net/yui/license.txt
-version: 2.4.1
+version: 2.5.1
 */
 /**
  * The Browser History Manager provides the ability to use the back/forward
@@ -11,8 +11,8 @@ version: 2.4.1
  *
  * This library requires the following static markup:
  *
- * <iframe id="yui-history-iframe" src="path-to-real-asset-in-same-domain"></iframe>
- * <input id="yui-history-field" type="hidden">
+ * &lt;iframe id="yui-history-iframe" src="path-to-real-asset-in-same-domain"&gt;&lt;/iframe&gt;
+ * &lt;input id="yui-history-field" type="hidden"&gt;
  *
  * @module history
  * @requires yahoo,event
@@ -538,7 +538,7 @@ YAHOO.util.History = (function () {
                 // As a consequence, the best thing we can do is to throw an
                 // exception. The application should catch it, and degrade
                 // gracefully. This is the sad state of history management.
-                throw new Error("Unsupported browser");
+                YAHOO.log("Unsupported browser.", "error", this.toString());
             }
 
             if (typeof stateField === "string") {
@@ -546,8 +546,8 @@ YAHOO.util.History = (function () {
             }
 
             if (!stateField ||
-                stateField.tagName !== "TEXTAREA" &&
-                (stateField.tagName !== "INPUT" ||
+                stateField.tagName.toUpperCase() !== "TEXTAREA" &&
+                (stateField.tagName.toUpperCase() !== "INPUT" ||
                  stateField.type !== "hidden" &&
                  stateField.type !== "text")) {
                 throw new Error("Missing or invalid argument");
@@ -561,7 +561,7 @@ YAHOO.util.History = (function () {
                     histFrame = document.getElementById(histFrame);
                 }
 
-                if (!histFrame || histFrame.tagName !== "IFRAME") {
+                if (!histFrame || histFrame.tagName.toUpperCase() !== "IFRAME") {
                     throw new Error("Missing or invalid argument");
                 }
 
@@ -631,9 +631,9 @@ YAHOO.util.History = (function () {
                 if (YAHOO.lang.hasOwnProperty(_modules, moduleName)) {
                     moduleObj = _modules[moduleName];
                     if (YAHOO.lang.hasOwnProperty(states, moduleName)) {
-                        currentState = states[moduleName];
+                        currentState = states[unescape(moduleName)];
                     } else {
-                        currentState = moduleObj.currentState;
+                        currentState = unescape(moduleObj.currentState);
                     }
 
                     // Make sure the strings passed in do not contain our separators "," and "|"
@@ -786,4 +786,4 @@ YAHOO.util.History = (function () {
     };
 
 })();
-YAHOO.register("history", YAHOO.util.History, {version: "2.4.1", build: "742"});
+YAHOO.register("history", YAHOO.util.History, {version: "2.5.1", build: "984"});
